
/*  

  vcool_mapfile.h
  
	Defines the structure of the data in the shared file mapping
	named VCOOL_SHARED_DATA
	
	 To access the data open the file mapping

		HANDLE hfm=OpenFileMapping(FILE_MAP_READ,FALSE,"VCOOL_SHARED_DATA");

	 and map a view to a VCOOL_DATA pointer (PVCOOL_DATA)
		PVCOOL_DATA pvd=(PVCOOL_DATA)MapViewOfFile(hfm,FILE_MAP_READ,0,0,0);
	  
	Access the data itself via the pointer

		DWORD CPU=pvd->dwCPU;
		
	You can also wait on a namend event to be notified when VCool has updated 
	the data. ftLastUpdate will only change when the temperatures 
	have been updated while the event may trigger when the user switched 
	the cool bit on or off as well.
	Note that the temperature update can be disabled by the user but the 
	cool bit will be updated in any case.

		HANDLE hEv=OpenEvent(SYNCHRONIZE,FALSE,"VCOOL_SHARED_DATA_EVENT");
		WaitForSingleObject(hEv,INFINITE);



	Remember to be nice and clean up once you're finished:
		UnmapViewOfFile(pvd);
		CloseHandle(hfm);
		CloseHandle(hEv);
		  
						  
*/

#pragma pack(push, vcool_mapfile_oldpack)	//store old pack setting

#pragma pack(8)								// use 8-byte alignment

typedef struct
{
	DWORD dwSize;				// site of VCOOL_DATA structure

	DWORD dwMajorVersion;       // VCool Major Version, e.g. 1 (V1.8b7)
	DWORD dwMinorVersion;		// VCool Minor Version, e.g. 8 (V1.8b7)
	DWORD dwBuild;				// VCool Build Version, e.g. 7 (V1.8b7)

	BOOLEAN bCoolBit;			// TRUE if cool bit currently set
	BOOLEAN bIdleLoop;			// TRUE if idle loop currently running

	DWORD dwPCIOption;			// current PCI Options (see below)
	DWORD dwUpdateInterval;     // Interval (seconds) of VCools data update

	FILETIME ftLastUpdate;		// (FILE)TIME (UTC) of last data update

	DWORD dwCPU;				// Temperature of CPU sensor
	DWORD dwSYS;				// Temperature of SYS sensor

	DWORD dwFan1;				// FAN #1 RPM
	DWORD dwFan2;				// FAN #2 RPM
	DWORD dwFan3;				// FAN #3 RPM

	DWORD dwThrottle;			// current CPU speed in %
} 
VCOOL_DATA,*PVCOOL_DATA;

#pragma pack(pop, vcool_mapfile_oldpack)	// retrieve old pack setting

/*

PCI Options :
	
	bit 14..31	-	reserved

	bit 13		-	HALT DETECT
	bit 12		-	CPU to PCI write buffer

	bit 11		-	DELAY TRANSACTION
	bit 10		-	Enhanced CPU to PCI write
	bit  9		-	PRIORITY ROTATION
	bit  8		-	FAIR ARBITRATION
	
	bit  7		-	Reduce 1T for CPU Read PCI Salve
	bit  6		-	Reduce 1T for FRAME Generation
	bit  5		-	MASTER READ CACHING
	bit  4		-	IDLE CYCLE REDUCTION			 

	bit	0..3	-	BUS TIMEOUT in x32 PCI Cycles
 */